domain

package
v0.1.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 27, 2025 License: MIT Imports: 5 Imported by: 1

Documentation

Index

Constants

const PublishedEventsMetricPointName = "published_events"
const ReceivedEventsMetricPointName = "received_events"

Variables

var (
	LogEventsScope = namespace.Namespace{Identifier: ReceivedEventsMetricPointName}

	LogEventsSubscriptionsScope = namespace.Namespace{Identifier: "subscriptions"}
	LogEventsReceivedScope      = namespace.Namespace{Identifier: "received"}
)
var (
	LogEventsSubscriptionChannelField = namespace.Namespace{Parent: &LogEventsSubscriptionsScope, Identifier: "channel"}
	LogEventsSubscriptionCountField   = namespace.Namespace{Parent: &LogEventsSubscriptionsScope, Identifier: "count"}
	LogEventsSubscriptionKindField    = namespace.Namespace{Parent: &LogEventsSubscriptionsScope, Identifier: "kind"}

	LogEventsReceivedChannelField       = namespace.Namespace{Parent: &LogEventsReceivedScope, Identifier: "channel"}
	LogEventsReceivedEventTypeField     = namespace.Namespace{Parent: &LogEventsReceivedScope, Identifier: "event_type"}
	LogEventsReceivedMessageIdField     = namespace.Namespace{Parent: &LogEventsReceivedScope, Identifier: "message_id"}
	LogEventsReceivedCorrelationIdField = namespace.Namespace{Parent: &LogEventsReceivedScope, Identifier: "correlation_id"}
	LogEventsReceivedPayloadField       = namespace.Namespace{Parent: &LogEventsReceivedScope, Identifier: "payload"}
	LogEventsReceivedStatusField        = namespace.Namespace{Parent: &LogEventsReceivedScope, Identifier: "status"}
)
var ErrEventHeaderShouldBeAString = errors.New("the event header should be a string but got an unsupported type")
var ErrFailedToValidateEventHeader = errors.New("failed to validate event header")
var ErrUnableToReadFromGroup = errors.New("unable to read from group")
var ErrUnableToUnmarshalEventHeader = errors.New("unable to unmarshal the header in a json document")

Functions

This section is empty.

Types

type EventHandler

type EventHandler interface {
	Register(event string, handler EventHandlerFunc)

	MsgReceived(ctx context.Context, event contract.Message, ack func())
}

type EventHandlerFunc

type EventHandlerFunc func(ctx context.Context, eventJson string) error

type EventUnmarshallingError added in v0.1.7

type EventUnmarshallingError[T any] struct {
	Event T
}

func (EventUnmarshallingError[T]) Error added in v0.1.7

func (e EventUnmarshallingError[T]) Error() string

type FailedToCreateStreamError added in v0.1.7

type FailedToCreateStreamError struct {
	Stream string
}

func (FailedToCreateStreamError) Error added in v0.1.7

type PublishableMessage

type PublishableMessage interface {
	Channel() string
	EventType() string
}

Jump to